mdt.gui.tk.single_subject.tabs package
======================================

Submodules
----------

mdt.gui.tk.single_subject.tabs.brain_mask module
------------------------------------------------

.. automodule:: mdt.gui.tk.single_subject.tabs.brain_mask
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.tk.single_subject.tabs.protocol module
----------------------------------------------

.. automodule:: mdt.gui.tk.single_subject.tabs.protocol
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.tk.single_subject.tabs.roi_mask module
----------------------------------------------

.. automodule:: mdt.gui.tk.single_subject.tabs.roi_mask
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.tk.single_subject.tabs.run_model module
-----------------------------------------------

.. automodule:: mdt.gui.tk.single_subject.tabs.run_model
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.tk.single_subject.tabs.view_results module
--------------------------------------------------

.. automodule:: mdt.gui.tk.single_subject.tabs.view_results
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mdt.gui.tk.single_subject.tabs
    :members:
    :undoc-members:
    :show-inheritance:
